<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:stsuuser="urn:ibm:names:ITFIM:1.0:stsuuser" version="1.0">

	<xsl:strip-space elements="*" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />

	<!--
		Initially we start with a copy of the document.
	-->
	<xsl:template match="@* | node()">
		<xsl:copy>
			<xsl:apply-templates select="@* | node()" />
		</xsl:copy>
	</xsl:template>

	<!--
		This template replaces the entire Principal element with one that contains 
		just the email address (from the ivcred tagvalue_email) and the data type 
		appropriate for SAML.
	-->
	<xsl:template match="//stsuuser:Principal">
		<stsuuser:Principal>
			<stsuuser:Attribute name="name" type="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress">
				<stsuuser:Value>
					<xsl:value-of select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_email'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" />
				</stsuuser:Value>
			</stsuuser:Attribute>
		</stsuuser:Principal>
	</xsl:template>

	<!--
		This template builds a new AttributeList. This involves:
		a) Adding an AuthenticationMethod attribute to meet SAML requirements. We assume
		this is always the "password" mechanism, regardless of what the TAM credential
		actually says.
		b) Map the tagvalue_name to commonName
		c) Map the tagvalue_ssn to ssn
		d) Add an Attribute to the AttributeList with name "role" and a value for each of
		the groups the user is in.
	-->
	<xsl:template match="//stsuuser:AttributeList">
		<stsuuser:AttributeList>

			<!-- First the authentcation method attribute -->
			<stsuuser:Attribute name="AuthenticationMethod" type="urn:oasis:names:tc:SAML:1.0:assertion">
				<stsuuser:Value>urn:oasis:names:tc:SAML:1.0:am:password</stsuuser:Value>
			</stsuuser:Attribute>

			<!-- Now the commonName attribute -->
			<stsuuser:Attribute name="commonName" type="http://example.com/federation/v1/commonName">
				<stsuuser:Value>
					<xsl:value-of select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_name'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" />
				</stsuuser:Value>
			</stsuuser:Attribute>

			<!-- Now the ssn attribute -->
			<stsuuser:Attribute name="ssn" type="http://example.com/federation/v1/namevalue">
				<stsuuser:Value>
					<xsl:value-of select="//stsuuser:AttributeList/stsuuser:Attribute[@name='tagvalue_ssn'][@type='urn:ibm:names:ITFIM:5.1:accessmanager']/stsuuser:Value" />
				</stsuuser:Value>
			</stsuuser:Attribute>

			<!-- Now the role attribute (can be multi-valued) -->
			<stsuuser:Attribute name="role" type="http://example.com/federation/v1/role">
				<xsl:for-each select="//stsuuser:GroupList/stsuuser:Group">
					<stsuuser:Value>
						<xsl:value-of select="@name" />
					</stsuuser:Value>
				</xsl:for-each>
			</stsuuser:Attribute>

		</stsuuser:AttributeList>
	</xsl:template>

</xsl:stylesheet>

